<?php

/*
 *   PhotoBase, PHP & MySQL based web photo gallery
 *   Copyright 2007,2008 Martin Plicka
 *   
 *   This file is part of PhotoBase.
 *
 *   PhotoBase is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *   PhotoBase is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with PhotoBase.  If not, see <http://www.gnu.org/licenses/>.
 */     
 
/**
 *  editcat.php
 *   
 *  Provides category creating, editing and deleting
 *  
 *  @author Martin Plicka  
 *  @version 1.0
 * 
 *  Parameters:
 *   GET [action] = new
 *                  edit
 *                  delete
 *   GET[state] =  0 - form / sending form
 *                 1 - acknowledgement
 *   GET[id]    =  ID of category to be modified/deleted 
 *   POST[send] = submit button  
 *   POST[name] = category name
 *   POST[description] = category description
 */ 

require_once './inc/tools.inc.php';
require_once './inc/login.inc.php';

$action = isset($_GET["action"])?$_GET["action"]:"new";

$state = isset($_GET["state"])?(int)$_GET["state"]:0;
if ($state < 0 || $state>1) $state = 0;

$id = isset($_GET["id"])?(int)$_GET["id"]:0;

switch($action) {
   case "delete":  
                   $LOCATION = $TITLE = lang_translate("Delete category");
                   break;
   case "edit":
                   $LOCATION = $TITLE =  lang_translate("Edit category");
                   break;
   case "new":
   default:        $action = "new";
                   $LOCATION = $TITLE = lang_translate("New category");
                   break;
}

$PAGER = lang_translate_replace("Step %1",$state+1);

switch ($state){

  /*
   * second phase, confirmation and also protection against form re-posting using browser refresh button.  
   */              
  case 1:
          include "./inc/header.inc.php";
          echo "<h1>".lang_translate("Done")."</h1>\n";
          switch($action){
                case "new":
                   echo "<p>".lang_translate("Category was created.")." <a href=\"./list.php?what=gal&amp;id=$id\">".lang_translate("Show")."</a>.</p>\n";
                   break;
                case "edit":
                   echo "<p>".lang_translate("Category was edited")." <a href=\"./list.php?what=gal&amp;id=$id\">".lang_translate("Show")."</a>.</p>\n";
                   break;
                case "delete":
                   echo "<p>".lang_translate("Category was deleted")." <a href=\"./list.php?what=cat&amp;id=$id\">".lang_translate("Go to the category list")."</a>.</p>\n";
                   break;
          
          
          }
          include "./inc/footer.inc.php";
          break;
  /*
   * first phase, input data, or re-input if verification has failed.
   */             
  case 0:
         $name ="";
         $description = "";
         
         switch($action) {
             case "delete":  
                   if (!login_isAdmin()) error(lang_translate("You are not administrator."));
                   break;
             case "edit":
                   if (!login_isAdmin()) error(lang_translate("You are not administrator."));
                   break;
             case "new":
             default:   
                   if (!login_isAdmin()) error(lang_translate("You are not administrator."));
                   break;
}

         /*
          * submit button pressed, posting data / action confirmed
          */          
         if (isset($_POST["send"])) {
           $name = unsafe_post("name");
           $description = (unsafe_post("description"));
           $msg = "";
           $break = false;

           switch($action){
           
              /**
               * edit existing category
               */                             
              case "edit":
                     if (!ereg("[^ ]+",$name)) { //musn't be empty
                       $msg .= lang_translate("Name must not be empty")."<br />"; $break = true;
                     }
                     if (!ereg("[^ ]+",$description)) { //musn't be empty
                       $msg .= lang_translate("Description must not be empty")."<br />";  $break = true;
                     }
                     if ($break) break;
                     $name1=safe_post("name");
                     $description1=safe_post("description");
                     $query = "UPDATE categories SET name='$name1', description='$description1' WHERE id=$id";
                   
                     $res = db_query($query,false);
                     if ($res) location("./editcat.php?action=$action&state=1&id=$id");
                     if (mysql_errno() > 0 && mysql_errno() != 1062) db_error (mysql_errno());
                     $msg = lang_translate("Category of this name already exists");
                  break;
              
              /**
               * creating new category
               */                                 
              case "new":
                     if (!ereg("[^ ]+",$name)) { //musn't be empty
                      $msg .= lang_translate("Name must not be empty")."<br />"; $break = true;
                     }
                     if (!ereg("[^ ]+",$description)) { //musn't be empty
                       $msg .= lang_translate("Description must not be empty")."<br />";  $break = true;
                     }
                     if($break) break;
                     
                     $name1=safe_post("name");
                     $description1=safe_post("description");
                     $query = "INSERT INTO categories (name,description) VALUES ('$name1','$description1');";
                     $res = db_query($query,false);
                     if ($res) location("./editcat.php?action=$action&state=1&id=".mysql_insert_id());
                     if (mysql_errno() > 0 && mysql_errno() != 1062) db_error ("");
                     $msg = lang_translate("Category of this name already exists");
                  break;
                 
              /**
               * deleting existing category
               */                
              case "delete":
                    if ($_POST["send"]!=lang_translate("Yes")) location ("./");
                    
                    // find files to be deleted
                    $query = "SELECT p.url FROM galleries g JOIN photos p ON(p.gallery = g.id) WHERE g.category=$id";
                    $res = db_query($query);
                    while ($row = mysql_fetch_row($res)) {
                      //delete big photo and also thumbnails of all sizes
                      @unlink("./photos/{$row[0]}");
                      foreach ($THUMB_SIZE as $tmp){
                        @unlink("./thumbs/{$tmp["w"]}-{$tmp["h"]}-{$row[0]}");
                      }
                    }
                    mysql_free_result($res);

                    //delete all photos (because of MyISAM engine - without constraints)
                    $query = "DELETE FROM photos WHERE gallery IN (SELECT id FROM galleries WHERE category = $id)";
                    db_query($query); //errors are detected by db_query()

                    //delete all galleries within category
                    $query = "DELETE FROM galleries WHERE category = $id";
                    db_query($query); //errors are detected by db_query()
                    
                    //category itself
                    $query = "DELETE FROM categories WHERE id = $id";
                    db_query($query); //errors are detected by db_query()
                    location("./editcat.php?action=$action&state=1");
                  break;     
                  
           }
        }
        /**
         * submit button not pressed, load data
         */                          
        else {
           switch ($action){
             case "edit":
                  $query = "SELECT name, description FROM categories WHERE id=$id";
                  $res = db_query ($query);
                  db_error_on_empty($res);
                  list ($name, $description) = mysql_fetch_row($res);
                  mysql_free_result($res);
                 break;
           }
        
        }
        
        
        /**
         * show form
         */                 
        include "./inc/header.inc.php";

        switch ($action){
        
           /**
            * editing/ creating
            */                       
           case "edit": case "new":
                   $name = hsc($name);
                   $description = hsc($description);

                   echo "
                   <script type=\"text/javascript\">
                      function check(){
                         a = document.getElementById(\"name1\");
                         if (! /[^ ]+/.test(a.value)) {
                            window.alert(\"".lang_translate("Name must not be empty")."\");
                            a.focus();
                            return false;
                         }
                         a = document.getElementById(\"description1\");
                         if (! /[^ ]+/.test(a.value)) {
                            window.alert(\"".lang_translate("Description must not be empty")."\");
                            a.focus();
                            return false;
                         }
                         return true;
                      }
                   </script> 
                   ";
                   echo "<div class=\"error\">$msg</div>";
                   echo "
                   
                      <form action=\"./editcat.php?action=$action&amp;id=$id\" method=\"post\" onsubmit=\"return check();\">
                        <label for=\"name1\" class=\"mandatory\">".lang_translate("Name")." *:</label><input type=\"text\" id=\"name1\" name=\"name\" value=\"".hsc($name)."\" maxlength=\"40\" size=\"40\" /><br />
                        <label for=\"description1\" class=\"mandatory\">".lang_translate("Description")." *</label><input type=\"text\" id=\"description1\" name=\"description\" value=\"".hsc($description)."\" maxlength=\"100\" size=\"50\" /><br />
                        <br />".lang_translate("Mandatory items marked with asterisk")."<br /><input type=\"submit\" name=\"send\" id=\"send1\" value=\"Uložit\" />
                      </form>
                      
                   ";
                   break;
                
           /** 
            * deleting - Yes/No buttons
            */                       
           case "delete":
               echo "
               <div class=\"error\">".lang_translate("Do you want to delete category, including all its galleries and photos?")."</div>
               <form action=\"./editcat.php?action=$action&amp;id=$id\" method=\"post\">
                 ".lang_translate("This action cannot be undone")."<br />
                 <input type=\"submit\" name=\"send\" value=\"".lang_translate("Yes")."\" />
                 <input type=\"submit\" name=\"send\" value=\"".lang_translate("No")."\" onclick=\"history.go(-1); return false;\" />
               </form>
              ";
              break;
        } //switch
        
              include "./inc/footer.inc.php";
}
?>
