<?php
/*
 *   PhotoBase, PHP & MySQL based web photo gallery
 *   Copyright 2007,2008 Martin Plicka
 *   
 *   This file is part of PhotoBase.
 *
 *   PhotoBase is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *   PhotoBase is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with PhotoBase.  If not, see <http://www.gnu.org/licenses/>.
 */      
 
/**
 * ftpupload.php
 * 
 * Allows mass photo posting using pre-uploaded photos via FTP.
 * Still Beta 
 *    
 * @author Martin Plicka 
 * @version 1.0
 * 
 * 
 * GET[state] = 0 - form
 *              1 - acknowledgement
 * GET[gallery] = default gallery ID for photo, used in new/edit form
 *   
 * POST[send] = submit button  
 * POST[gallery]  = pre-filled gallery ID
 */ 
 
define("FILE_OK",0);
define("FILE_NOT_JPEG",1);
define("FILE_TOO_LARGE",2);
define("FILE_STRANGE_DIM",3); 
 
require_once './inc/tools.inc.php';
require_once './inc/login.inc.php';

/**
 * scans upload directory of logged user and try all files to be JPEG images
 * @param output variable for array which will contain file list after function finishes
 * @return true if all files in upload directory are JPEG images, otherwise false
 */   
function scanUploadDir(&$output){
   global $UPLOAD_MAX_SIZE;
   $output = Array();
   
   $upload_dir =  './upload/'.login_name().'/';
   $handle=opendir($upload_dir);
   
   $bool = true;
   
   while (false!==($file = readdir($handle))) {
     if ($file != "." && $file != "..") {
         $filename = $upload_dir.$file;
         $size = getimagesize($filename); 
         
         if ($size[2] != IMAGETYPE_JPEG) {
           $output[$file] = FILE_NOT_JPEG;
           $bool = false;
           continue;
         }
         if (filesize($filename)>$UPLOAD_MAX_SIZE) {
           $output[$file] = FILE_TOO_LARGE;
           $bool = false;
           continue;   
         }
         $ratio = (double)$size[0]/(double)$size[1];
         if ($ratio > 5 || $ratio < 0.2) {
            $output[$file] = FILE_STRANGE_DIM;
            $bool = false;
            continue;   
         }  
         $output[$file] = FILE_OK;   
     }
   }
   closedir($handle);
   return $bool;
}

/** 
 * SCRIPT BEGIN
 */ 
if (!login_isLogged()) error (lang_translate("Not logged in"));
$state = isset($_GET["state"])?(int)$_GET["state"]:0;
if ($state < 0 || $state>1) $state = 0;

$gallery = isset($_GET["gallery"])?(int)$_GET["gallery"]:0;

$TITLE = $LOCATION = lang_translate("Mass upload via FTP")." (BETA)";

$PAGER = lang_translate_replace("Step %1",$state+1);


switch ($state){
  /**
   * Acknowledgement
   */     
  case 1:
      include "./inc/header.inc.php";
      echo "<h1>".lang_translate("Done")."</h1>\n";
      echo "<p>".lang_translate("Photos were posted").". <a href=\"./list.php?what=photos&id=$gallery\">".lang_translate("Show")."</a>. \n";
      $filestodelete = urldecode($_GET["filestodelete"]);
      if ($filestodelete) {
        echo "<div class=\"error\">".lang_translate("Following files in your upload directory couldn't been deleted. Delete them manually.")."</div>";
        
        echo "<ul class=\"filelist\">";
        $arr = explode('||',$filestodelete);
        foreach ($arr as $file) {
           echo "<li>$file</li>";
        }
        echo "</ul>";
      }
      include "./inc/footer.inc.php";
      break;
  
  /**
   * Upload page
   */             
  case 0:
      if (!login_isCreator()) error(lang_translate("You cannot make galleries."));
      
      if (!file_exists("./upload/".login_name()) ) error (lang_translate("Directory for FTP upload does not exist. Ask administrator to create an FTP account for you."));
      $upload_dir =  './upload/'.login_name().'/';
      
      //stisknuto tlacitko odeslat
      if (isset($_POST["send"])) {
        $gallery = isset($_POST["gallery"])?(int)$_POST["gallery"]:0;
      
       //does logged user own this gallery?
       $query = "SELECT id FROM galleries WHERE id=$gallery AND user=".login_id().";";
       $res=db_query($query);
       db_error_on_empty($res);
       mysql_free_result($res);

       if (($dir_ok = scanUploadDir($dir) && ( count($dir) > 0) ) ) {
         $filestodelete = Array();
         foreach ($dir as $file => $info) {
            $query = "INSERT INTO photos (description,gallery,url) VALUES ('',$gallery,'error_when_found');";
            $res = db_query($query);
            $id = mysql_insert_id();
            $new_url = str_pad(login_id(), 3, "0", STR_PAD_LEFT)."_".str_pad($id, 10, "0", STR_PAD_LEFT).".jpg";
            $query = "UPDATE photos SET url = '$new_url' WHERE id = $id;";
            db_query($query);
     
            //change to copy and remove
            $new_url = "./photos/$new_url";
            $file = $upload_dir.$file;
          
            if (!rename($file,$new_url)) {
              $filestodelete[] = $file;
              if (!copy($file,$new_url)) error ("Doslo k chybe pri ulozeni, kontaktujte administratora");
            }
          
     
         }
         //state 2, link to gallery
         location("./ftpupload.php?state=1&gallery=$gallery&filestodelete=".urlencode(implode("||",$filestodelete)));
       }

      }
      
    //both cases, submited or not       
    include "./inc/header.inc.php";
    
    //scan wasn't executed before
    if (!isset($dir_ok)) $dir_ok = scanUploadDir($dir);
    
    //some file is found
    if (count($dir)>0) {
    
      echo "<div>
        ".lang_translate("Your upload directory contains following files").":
      </div>";
      echo "<ul class=\"filelist\">\n";
      
      //each file found
      foreach ($dir as $file => $info){
        echo "<li>$file - ";
        switch ($info) {
         case FILE_NOT_JPEG: echo "<span class=\"red\">".lang_translate("Picture is not JPEG")."</span>"; break;
         case FILE_TOO_LARGE: echo "<span class=\"red\">".lang_translate("Uploaded file is too large")."</span>"; break;
         case FILE_STRANGE_DIM: echo "<span class=\"red\">".lang_translate("Picture has strange dimensions")."</span>"; break;
         case FILE_OK: default: echo "OK"; break;
        }
        echo "</li>";
      }
      echo "</ul>\n";
   
      //some files are not jpeg
      if (!$dir_ok)
         echo "<div".((isset($_POST["send"]))?" class=\"error\"":"").">
           ".lang_translate("Correct files noted with error, otherwise no photo will be saved")."
         </div>";

      echo "<div>
        ".lang_translate("Select gallery and click on the Save button")."
       </div>";

      $query = "SELECT c.id,c.name,g.id,g.name FROM categories c JOIN galleries g ON (g.category = c.id) WHERE g.user=".login_id()." ORDER BY c.name, g.name;";
      $res = db_query($query);
      if (db_empty($res)) error(lang_translate("You do not own any gallery. You must create some first."));

      echo " 
         <form enctype=\"multipart/form-data\" action=\"./ftpupload.php\" method=\"post\" onsubmit=\"return check();\">\n";
        
      echo "<label for=\"gallery1\" class=\"mandatory\">".lang_translate("Gallery")." *</label><select name=\"gallery\" id=\"gallery1\">\n";
  
      $i=0;
      while ($row = mysql_fetch_row($res)) {
          if($row[0]!=$i) {
          if ($i!=0) echo "</optgroup>\n";
          echo "<optgroup label=\"{$row[1]}\">\n";
          $i = $row[0];
        }
        echo "<option value=\"{$row[2]}\"".(($row[2]==$gallery)?" selected=\"selected\"":"").">".hsc($row[3])."</option>\n";
      }
      echo "</optgroup></select><br />\n";
          
      mysql_free_result($res);
          
      echo "
        <input type=\"submit\" name=\"send\" id=\"send1\" value=\"".lang_translate("Save")."\" />
        </form>
      ";
    }
    else {
      echo "<div>".lang_translate("Your upload directory contains no photos. Upload some first")."</div>
        <div><a onclick=\"window.location.reload(); return false;\" href=\"{$_SERVER["REQUEST_URI"]}\">Obnovit</a></div>
      ";
    }
    include "./inc/footer.inc.php";
  break;
  //end of case 0 - upload form
}

?>
