<?php
/*
 *   PhotoBase, PHP & MySQL based web photo gallery
 *   Copyright 2007,2008 Martin Plicka
 *   
 *   This file is part of PhotoBase.
 *
 *   PhotoBase is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *   PhotoBase is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with PhotoBase.  If not, see <http://www.gnu.org/licenses/>.
 */     

/**
 * inc/login.inc.php
 * 
 * Functions for authentification purposes.
 *  
 * @version 1.0
 * @author Martin Plicka     
 */ 
 
session_start();

require_once "./inc/db.inc.php";
require_once './inc/tools.inc.php';


/**
 * definuje ciselne vyjadreni hodnot v mnozine s pravy uzivatele v databazi
 */ 
define ("RIGHTS_MODERATOR",16);
define ("RIGHTS_COMMENTATOR",8);
define ("RIGHTS_CREATOR",4);
define ("RIGHTS_ADMIN",2);
define ("RIGHTS_WANTCREATOR",1);

/**
 * textovy popis prav
 */ 
$LOGIN_RIGHT_NAME[RIGHTS_WANTCREATOR] = "<b>Wanna store photos</b>";
$LOGIN_RIGHT_NAME[RIGHTS_ADMIN] = "Manages";
$LOGIN_RIGHT_NAME[RIGHTS_CREATOR] = "Store photos";
$LOGIN_RIGHT_NAME[RIGHTS_COMMENTATOR] = "Comments";
$LOGIN_RIGHT_NAME[RIGHTS_MODERATOR] = "Moderates";

/**
 * analyzuje a vraci retezec popisujici veskera prava uzivatele
 * @param ciselne vyjadreni prav
 * @return retezec obsahujici vycet prav
 */   
function login_rights_print($what) {
  global $LOGIN_RIGHT_NAME;
  foreach ($LOGIN_RIGHT_NAME as $KEY => $VALUE) {
     if ($what & $KEY) $tmp[]=lang_translate($VALUE);
  }
  return implode(", ",$tmp);
}

/**
 * vypisuje prihlasovaci formular
 * @param userPrefill predvyplnene uzivatelske jmeno
 * @param goBack url stranky pro navrat po uspesnem prihlaseni  
 */
function login_echoForm($userPrefill, $goBack){
  global $LOGIN;
  if ($goBack=="") $goBack = $_SERVER["REQUEST_URI"];
  if (login_isLogged()){
   echo "<div id=\"loginform\">".lang_translate_replace("User %1 logged in","<b>".login_name()."</b>")."<br /><a href=\"login.php?action=logout&amp;goback=".urlencode($goBack)."\">".lang_translate("Logout")."</a></div>"; 
  }
  else echo '
    <script type="text/javascript">
      function loginInputCheck(){
        a = document.getElementById("login1");
        if (a.value == "") {
          window.alert("Zadejte uživatelské jméno");
          a.focus();
         return false;
       }
       return true;
     }
   </script> 
   <div id="loginform">   
      <form action="login.php?action=login&amp;goback='.urlencode($goBack).'" method="post"  onsubmit="return loginInputCheck();" >
            <label for="login1">'.lang_translate("Loginname").':</label> <input class="text" type="text" name="login" id="login1" maxlength="20" value="'.hsc($userPrefill).'" /><br />
            <label for="pass1">'.lang_translate("Password").':</label> <input class="text" type="password" name="pass" id="pass1" /><br />
            <input type="submit" value="'.lang_translate("Login").'" class="button" />
            <a href="./register.php">'.lang_translate("New account").'</a>
      </form>
   </div>
   ';
}
  
/**
 * Provede prihlaseni
 * @param username uzivatelske jmeno
 * @param password heslo
 * @return true pri uspechu
 */    
function login_login($username, $password){
    global $DB;
    $query = "SELECT id, login, email, rights+0 AS rights FROM users where login='".addslashes ($username)."' AND pass = '".md5($password)."';";
    $result = db_query($query);
    if (mysql_num_rows($result) != 1) {
      mysql_free_result($result);
      return false;
    }
    $pole = mysql_fetch_array($result);
    $_SESSION["LOGIN_NAME"] = $pole["login"];
    $_SESSION["LOGIN_ID"] = $pole["id"];
    $_SESSION["LOGIN_EMAIL"] = $pole["email"];
    $_SESSION["LOGIN_RIGHTS"] = $pole["rights"];
    mysql_free_result($result);
    return true;
}

/** 
 * Provede odhlaseni
 */ 
function login_logout(){
    unset($_SESSION["LOGIN_NAME"]);
    unset($_SESSION["LOGIN_ID"]);
    unset($_SESSION["LOGIN_EMAIL"]);
    unset($_SESSION["LOGIN_RIGHTS"]);
}

/**
 * Overi, zda je uzivatel prihlasen
 * @return true, pokud je nekdo prihlasen
 */  
function login_isLogged(){
   return (isset($_SESSION["LOGIN_NAME"]) && isset($_SESSION["LOGIN_ID"]) 
   && isset($_SESSION["LOGIN_EMAIL"]) && isset($_SESSION["LOGIN_RIGHTS"]));
}
  
function login_name(){
    return login_isLogged()?$_SESSION["LOGIN_NAME"]:"" ;
}
  
function login_id(){
    return login_isLogged()?$_SESSION["LOGIN_ID"]:0 ;
}
  
function login_email(){
    return login_isLogged()?$_SESSION["LOGIN_EMAIL"]:"" ;
}
    
function login_isCreator(){
    return login_isLogged()?((bool)($_SESSION["LOGIN_RIGHTS"] & RIGHTS_CREATOR)):false;
}
  
function login_isAdmin(){
   return login_isLogged()?((bool)($_SESSION["LOGIN_RIGHTS"] & RIGHTS_ADMIN)):false;
}
  
function login_isCommentator(){
   return login_isLogged()?((bool)($_SESSION["LOGIN_RIGHTS"] & RIGHTS_COMMENTATOR)):false;
}
  
function login_isModerator(){
    return login_isLogged()?((bool)($_SESSION["LOGIN_RIGHTS"] & RIGHTS_MODERATOR)):false;
}
  
function login_rights(){
    return $_SESSION["LOGIN_RIGHTS"];
}


/**
 * Provede znovunacteni pristupovych prav z databaze
 */ 
function login_recheck(){
    if (!login_isLogged()) return;
    $query = "SELECT 0+rights FROM users where id=".login_id().";";
    $res = db_query($query);
    if (mysql_num_rows($res) != 1) {
       login_logout();
       error (lang_translate("You account was erased."));
    }
    $row = mysql_fetch_row($res);
    $_SESSION["LOGIN_RIGHTS"] = $row[0];
    mysql_free_result($res);
}
  
if (!(isset($DB_NO_CONNECTION) && $DB_NO_CONNECTION == 1)) login_recheck();

?>
