<?php
/*
 *   PhotoBase, PHP & MySQL based web photo gallery
 *   Copyright 2007,2008 Martin Plicka
 *   
 *   This file is part of PhotoBase.
 *
 *   PhotoBase is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *   PhotoBase is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with PhotoBase.  If not, see <http://www.gnu.org/licenses/>.
 */      
 
/**
 * list.php
 * 
 * Lists categories, galleries, and photos within gallery
 *    
 * @author Martin Plicka 
 * @version 1.0
 *  
 * GET[what] = 
 *             cat - categories list
 *             gal - galleries list, within given category
 *             photos - photos list, within given gallery
 * GET[id] =  category ID, for GET[what] = gal
 *            gallery ID, for GET[what] = photos 
 * GET[page] = page number
 * GET[limit] = number of items displayed in page at once
 */ 
 
require_once './inc/setup.inc.php';
require_once './inc/db.inc.php';
require_once "./inc/login.inc.php";



$what = isset($_GET["what"])?$_GET["what"]:"cat";

$id = isset($_GET["id"])?(int)$_GET["id"]:0;
$id = $id>0?$id:0;

// offset, min 0
$page = isset($_GET["page"])?(int)$_GET["page"]:0;
if ($page<0) $page = 0;


if ($id==0) $what = "cat";

/**
 * Calculate number of pages
 */ 
switch ($what){
 case "gal":
      $query="SELECT count(id) as count FROM galleries WHERE category=$id;";
      break;
 
 case "photos": 
     $query="SELECT count(id) as count FROM photos WHERE gallery=$id;";
     break;
 
 case "cat": 
 default: 
     $query="SELECT count(id) as count FROM categories;";
     $what = "cat";
     break;
}

// limit, min 1
$limit_default = "LIMIT_".strtoupper($what);
$limit = isset($_COOKIE[$limit_default])?(int)$_COOKIE[$limit_default]:$$limit_default;
if ($limit<=0) $limit = $$limit_default;

if (isset($_GET["limit"]) && is_numeric($_GET["limit"]) && ((int)$_GET["limit"]) > 0 ){
   $limit = (int)$_GET["limit"];
   setcookie($limit_default, $limit,time()+60*60*24*30);
}


$res = db_query($query);
if (db_empty($res)) db_error("DB error");
$row = mysql_fetch_row($res);
mysql_free_result($res);
$count = $row[0];

$maxpage = max(0,ceil($count / $limit) - 1);
if ($page > $maxpage) $page = $maxpage;

/*************** PAGER************************/

$min = max($page-4,0);
$max = min($page+4, $maxpage);

//fill array with number of pages to be writen within PAGER

$pager_array[]=0; //first page

for ($i = $min+1; $i<$max; $i++) {
 $pager_array[]=$i; //3 back and 3 forward from current page
}

if ($maxpage!=0) $pager_array[]=($maxpage); //last page


if ($page > 0) $PAGER.= "<a href=\"./list.php?what=$what&amp;id=$id&amp;limit=$limit&amp;page=".($page-1)."\">&lt;</a> ";
for ($i = 0; $i<count($pager_array); $i++) {
    if ($i == 1 && $pager_array[0]<$pager_array[1]-1) $PAGER.= ".. ";
    if ($page!=$pager_array[$i])
        $PAGER.= "<a href=\"./list.php?what=$what&amp;id=$id&amp;limit=$limit&amp;page=".($pager_array[$i])."\">".($pager_array[$i]+1)."</a> ";
    else $PAGER.= "<a class=\"actual\">".($pager_array[$i]+1)."</a> ";
    if ($i == count($pager_array)-2 && $pager_array[$i]<$pager_array[$i+1]-1) $PAGER.= ".. ";
}
if ($page < $maxpage) $PAGER.= "<a href=\"./list.php?what=$what&amp;id=$id&amp;limit=$limit&amp;page=".($page+1)."\">&gt;</a> ";


/**************** LOCATION ********************/
switch ($what){
 case "gal":
    $query="SELECT name FROM categories WHERE id = $id;";
    $res = db_query($query);
    db_error_on_empty($res);
    $row = mysql_fetch_row($res);
    mysql_free_result($res);
    $TITLE = lang_translate("Category").": ${row[0]}";
    $LOCATION = hsc($row[0]);
    break;
 
 case "photos":
    $query="SELECT g.name, c.name, c.id, g.user FROM galleries g LEFT JOIN categories c ON (g.category = c.id) WHERE g.id=$id;";
    $res = db_query($query);
    db_error_on_empty($res);
    $row = mysql_fetch_row($res);
    mysql_free_result($res);
    $LOCATION = "<a href=\"./list.php?what=gal&amp;id={$row[2]}\">".hsc($row[1])."</a> / ".hsc($row[0]);
    $TITLE = lang_translate("Gallery").": ${row[0]}";
    $owner = (int)$row[3];
    break;
 
 case "cat": 
    $LOCATION = "";
    $TITLE = lang_translate("Category list");
    break;
}


/***************** LIST ************************/
include "./inc/header.inc.php";

echo "
<div id=\"limiter\"> 
  <form action=\"./list.php\" method=\"get\">
    <input type=\"hidden\" name=\"what\" value=\"$what\" />
    <input type=\"hidden\" name=\"id\" value=\"$id\" />
    <input type=\"hidden\" name=\"page\" value=\"$page\" /> 
    <label for=\"limit1\">".lang_translate("Number of items displayed").":</label>
  <select id=\"limit1\" name=\"limit\" onchange=\"submit();\">\n";
if ($what == "photos") {
  if ($limit != 10 && $limit != 20 && $limit != 40 && $limit != 60) echo "
    <option value=\"x\">(".lang_translate("select").")</option>
  ";
  echo "
    <option value=\"10\"".($limit==10?" selected=\"selected\"":"").">10</option>
    <option value=\"20\"".($limit==20?" selected=\"selected\"":"").">20</option>
    <option value=\"40\"".($limit==40?" selected=\"selected\"":"").">40</option>
    <option value=\"60\"".($limit==60?" selected=\"selected\"":"").">60</option>
  ";
}
else {
  if ($limit != 4 && $limit != 8 && $limit != 12 && $limit != 16)echo "<option value=\"x\">(".lang_translate("select").")</option>";
  echo "
    <option value=\"4\"".($limit==4?" selected=\"selected\"":"").">4</option>
    <option value=\"8\"".($limit==8?" selected=\"selected\"":"").">8</option>
    <option value=\"12\"".($limit==12?" selected=\"selected\"":"").">12</option>
    <option value=\"16\"".($limit==16?" selected=\"selected\"":"").">16</option>
  ";

}
echo "
  </select>
    <input type=\"submit\" value=\"OK\"/>
  </form>
</div>
";

$offset = $page * $limit;

switch ($what){
 case "gal":
    if (login_isCreator() || login_isAdmin()) { 
       echo "<div class=\"admin\">
       ";
       
       if (login_isCreator()) echo "<a href=\"./editgal.php?action=new&amp;category=$id\">".lang_translate("Add gallery")."</a>
       ";
       
       if (login_isCreator() && login_isAdmin()) echo " - 
       ";
       
       if (login_isAdmin()) echo "<a href=\"./editcat.php?action=edit&amp;id=$id\">".lang_translate("Edit category")."</a> 
       - <a href=\"./editcat.php?action=delete&amp;id=$id\">".lang_translate("Delete category")."</a>
       ";
       
       echo "</div>
       ";
    }
    $query="SELECT g.id, g.name, g.description, u.name, g.user, DATE_FORMAT(max(p.time),'%e.%m.%Y - %H:%i'), count(p.id), p.url FROM galleries g LEFT JOIN users u ON (g.user = u.id) LEFT JOIN photos p ON (p.gallery = g.id) WHERE category=$id GROUP BY g.id ORDER BY g.name LIMIT $offset, $limit;";
    break;
 
 case "photos":
    if ((login_isCreator() && $owner == login_id()) || login_isAdmin()) {
      echo "<div class=\"admin\">
      ";
      
      if (login_isCreator() && $owner == login_id()) echo "<a href=\"./editphoto.php?action=new&amp;gallery=$id\">".lang_translate("Insert photo")."</a> - <a href=\"./ftpupload.php?gallery=$id\">".lang_translate("Mass upload via FTP")."</a> - 
      ";

      echo "<a href=\"./editgal.php?action=edit&amp;id=$id\">".lang_translate("Edit gallery")."</a> 
      - <a href=\"./editgal.php?action=delete&amp;id=$id\">".lang_translate("Delete gallery")."</a>
      ";
      
      echo "</div>
      ";
    }
    $query="SELECT p.id, description, url, DATE_FORMAT(p.time,'%e.%m.%Y - %H:%i'), count(c.id) FROM photos p LEFT JOIN comments c ON (c.photo = p.id) WHERE gallery=$id GROUP BY p.id ORDER BY p.id DESC LIMIT $offset, $limit;";
    break;
 
 case "cat": 
    if (login_isAdmin()) echo "
      <div class=\"admin\">
        <a href=\"./editcat.php?action=new\">".lang_translate("Add category")."</a>
      </div>";
    $query="SELECT c.id, c.name, c.description, DATE_FORMAT(max(p.time),'%e.%m.%Y - %H:%i'), count(p.id), count(distinct g.id) FROM categories c LEFT JOIN galleries g ON (c.id = g.category) LEFT JOIN photos p ON (p.gallery = g.id) GROUP BY (c.id) ORDER BY name LIMIT $offset, $limit;";
    break;
}

$res = db_query($query);
if (db_empty($res)) echo "<div class=\"list_empty\">".lang_translate("No items")."</div>";
echo "
  <br class=\"hide\" />
  
  <div id=\"list_$what\">
";

switch ($what){
  case "gal": 
    while ($row = mysql_fetch_array($res)){
      echo "<div class=\"list_item\">
      ";
      
      if ($row[7] != "")
      echo "
      <div class=\"list_thumb\">
        <img src=\"./thumb.php?src=".urlencode($row[7])."&amp;size=2\" alt=\"".lang_translate("Thumbnail")."\" />
      </div>
      ";
      
      echo "
        <h2 class=\"list_head\">
          <a href=\"./list.php?what=photos&amp;id={$row[0]}\">".hsc($row[1])."</a>
        </h2>
      ";
      
      echo "
        <div class=\"list_body\">".hsc($row[2])."
          <div class=\"time\">".lang_translate_replace("%1 photos",$row[6]).", ".lang_translate_replace("author %1",hsc($row[3]))."<br />
          ".lang_translate_replace("Last photo posted %1", $row[5])."
        </div>
      ";
      
      if (login_id()==$row[4] || login_isAdmin()) {
        echo "
          <div class=\"admin\">
        ";
        
        if (login_id()==$row[4]) echo "
          <a href=\"./editphoto.php?action=new&amp;gallery={$row[0]}\">".lang_translate("Insert photo")."</a> - 
        ";
        echo "
          <a href=\"./editgal.php?action=edit&amp;id={$row[0]}\">".lang_translate("Edit")."</a> - 
          <a href=\"./editgal.php?action=delete&amp;id={$row[0]}\">".lang_translate("Delete")."</a>
        
          </div>
        ";
      }
      echo "
          </div>
        </div>
        <br class=\"hide\" />
      ";
    }
    break;
 
  case "photos": 
    while ($row = mysql_fetch_array($res)){
        
       echo "
         <div class=\"thumb\" title=\"".hsc($row[1])."\">
           <a href=\"./view.php?id=".$row[0]."\"><img alt=\"".lang_translate("Thumbnail")."\" src=\"./thumb.php?size=0&amp;src=".urlencode($row[2])."\" /></a>
         <div class=\"time\">
           ".hsc($row[3])."<br />".lang_translate_replace("%1 comments",$row[4] )."
         </div>
       ";
       if (login_isAdmin() || login_isCreator() && $owner==login_id()) {
          echo "
            <div class=\"admin\">
              <a href=\"./editphoto.php?action=edit&amp;id={$row[0]}\">".lang_translate("Edit")."</a>
               - 
              <a href=\"./editphoto.php?action=delete&amp;id={$row[0]}\">".lang_translate("Delete")."</a>
            </div>
          ";
       }
       echo "
         </div>
         <br class=\"hide\" />
       ";
    }
    echo "
      <br class=\"clear\" />
    ";
    break;
 
  case "cat":
    while ($row = mysql_fetch_array($res)){
      echo "
        <div class=\"list_item\">
          <h2 class=\"list_head\">
            <a href=\"./list.php?what=gal&amp;id={$row[0]}\">".hsc($row[1])."</a>
          </h2>
          <div class=\"list_body\">
            ".hsc($row[2])."
              <div class=\"time\">".lang_translate_replace("%1 photos in %2 galleries",$row[4],$row[5])."<br />
              ".lang_translate_replace("Last photo posted %1",$row[3])."
          </div>
      ";
      if (login_isAdmin() || login_isCreator()) {
        echo "<div class=\"admin\">
        ";
        
        if (login_isCreator()) {
          echo "<a href=\"./editgal.php?action=new&amp;category={$row[0]}\">".lang_translate("Add gallery")."</a>
          ";
        }
        if (login_isAdmin() && login_isCreator()) echo " - ";
        if (login_isAdmin()) echo "
          <a href=\"./editcat.php?action=edit&amp;id={$row[0]}\">".lang_translate("Edit")."</a> - 
          <a href=\"./editcat.php?action=delete&amp;id={$row[0]}\">".lang_translate("Delete")."</a>
        ";
        
        echo "
          </div>
        ";
      }
      echo "
          </div>
        </div>
        <br class=\"hide\" />
      ";
    }
    break;
}

mysql_free_result($res);
echo "
  </div>
  <br class=\"clear\" />
";

include "./inc/footer.inc.php";
?>
